$KalamSyncDatabaseManager class
Constructors
- $KalamSyncDatabaseManager(_$KalamSyncDatabase _db)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- kalamActions → $$KalamActionsTableTableManager
-
no setter
- kalamActionSteps → $$KalamActionStepsTableTableManager
-
no setter
- kalamCachedRows → $$KalamCachedRowsTableTableManager
-
no setter
- kalamCheckpoints → $$KalamCheckpointsTableTableManager
-
no setter
- kalamRowStates → $$KalamRowStatesTableTableManager
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited