KalamActionStepsCompanion class

Inheritance

Constructors

KalamActionStepsCompanion({Value<String> actionId = const Value.absent(), Value<String> name = const Value.absent(), Value<String> status = const Value.absent(), Value<String?> resultJson = const Value.absent(), Value<String?> lastError = const Value.absent(), Value<DateTime> updatedAt = const Value.absent(), Value<int> rowid = const Value.absent()})
const
KalamActionStepsCompanion.insert({required String actionId, required String name, required String status, Value<String?> resultJson = const Value.absent(), Value<String?> lastError = const Value.absent(), required DateTime updatedAt, Value<int> rowid = const Value.absent()})

Properties

actionId Value<String>
final
hashCode int
The hash code for this object.
no setterinherited
lastError Value<String?>
final
name Value<String>
final
resultJson Value<String?>
final
rowid Value<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status Value<String>
final
updatedAt Value<DateTime>
final

Methods

copyWith({Value<String>? actionId, Value<String>? name, Value<String>? status, Value<String?>? resultJson, Value<String?>? lastError, Value<DateTime>? updatedAt, Value<int>? rowid}) KalamActionStepsCompanion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom({Expression<String>? actionId, Expression<String>? name, Expression<String>? status, Expression<String>? resultJson, Expression<String>? lastError, Expression<DateTime>? updatedAt, Expression<int>? rowid}) Insertable<StoredActionStep>