KalamCachedRowsCompanion class

Inheritance

Constructors

KalamCachedRowsCompanion({Value<String> accountKey = const Value.absent(), Value<String> tableId = const Value.absent(), Value<String> rowKey = const Value.absent(), Value<String> valuesJson = const Value.absent(), Value<DateTime> updatedAt = const Value.absent(), Value<int> rowid = const Value.absent()})
const
KalamCachedRowsCompanion.insert({required String accountKey, required String tableId, required String rowKey, required String valuesJson, required DateTime updatedAt, Value<int> rowid = const Value.absent()})

Properties

accountKey Value<String>
final
hashCode int
The hash code for this object.
no setterinherited
rowid Value<int>
final
rowKey Value<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tableId Value<String>
final
updatedAt Value<DateTime>
final
valuesJson Value<String>
final

Methods

copyWith({Value<String>? accountKey, Value<String>? tableId, Value<String>? rowKey, Value<String>? valuesJson, Value<DateTime>? updatedAt, Value<int>? rowid}) KalamCachedRowsCompanion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom({Expression<String>? accountKey, Expression<String>? tableId, Expression<String>? rowKey, Expression<String>? valuesJson, Expression<DateTime>? updatedAt, Expression<int>? rowid}) Insertable<StoredCachedRow>