KalamCheckpointsCompanion class

Inheritance

Constructors

KalamCheckpointsCompanion({Value<String> accountKey = const Value.absent(), Value<String> subscriptionId = const Value.absent(), Value<String> seq = const Value.absent(), Value<DateTime> updatedAt = const Value.absent(), Value<int> rowid = const Value.absent()})
const
KalamCheckpointsCompanion.insert({required String accountKey, required String subscriptionId, required String seq, required DateTime updatedAt, Value<int> rowid = const Value.absent()})

Properties

accountKey Value<String>
final
hashCode int
The hash code for this object.
no setterinherited
rowid Value<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seq Value<String>
final
subscriptionId Value<String>
final
updatedAt Value<DateTime>
final

Methods

copyWith({Value<String>? accountKey, Value<String>? subscriptionId, Value<String>? seq, Value<DateTime>? updatedAt, Value<int>? rowid}) KalamCheckpointsCompanion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom({Expression<String>? accountKey, Expression<String>? subscriptionId, Expression<String>? seq, Expression<DateTime>? updatedAt, Expression<int>? rowid}) Insertable<StoredCheckpoint>