StoredActionStep class

Inheritance
Implemented types

Constructors

StoredActionStep({required String actionId, required String name, required String status, String? resultJson, String? lastError, required DateTime updatedAt})
const
StoredActionStep.fromJson(Map<String, dynamic> json, {ValueSerializer? serializer})
factory

Properties

actionId String
final
hashCode int
The hash code for this object.
no setteroverride
lastError String?
final
name String
final
resultJson String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final
updatedAt DateTime
final

Methods

copyWith({String? actionId, String? name, String? status, Value<String?> resultJson = const Value.absent(), Value<String?> lastError = const Value.absent(), DateTime? updatedAt}) StoredActionStep
copyWithCompanion(KalamActionStepsCompanion data) StoredActionStep
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
override
toCompanion(bool nullToAbsent) KalamActionStepsCompanion
toJson({ValueSerializer? serializer}) Map<String, dynamic>
Converts this object into a representation that can be encoded with json. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
override
toJsonString({ValueSerializer? serializer}) String
Converts this object into a json representation. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override