StoredCachedRow class

Inheritance
Implemented types

Constructors

StoredCachedRow({required String accountKey, required String tableId, required String rowKey, required String valuesJson, required DateTime updatedAt})
const
StoredCachedRow.fromJson(Map<String, dynamic> json, {ValueSerializer? serializer})
factory

Properties

accountKey String
final
hashCode int
The hash code for this object.
no setteroverride
rowKey String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tableId String
final
updatedAt DateTime
final
valuesJson String
final

Methods

copyWith({String? accountKey, String? tableId, String? rowKey, String? valuesJson, DateTime? updatedAt}) StoredCachedRow
copyWithCompanion(KalamCachedRowsCompanion data) StoredCachedRow
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
override
toCompanion(bool nullToAbsent) KalamCachedRowsCompanion
toJson({ValueSerializer? serializer}) Map<String, dynamic>
Converts this object into a representation that can be encoded with json. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
override
toJsonString({ValueSerializer? serializer}) String
Converts this object into a json representation. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override