StoredCheckpoint class
- Inheritance
- Implemented types
Constructors
- StoredCheckpoint({required String accountKey, required String subscriptionId, required String seq, required DateTime updatedAt})
-
const
-
StoredCheckpoint.fromJson(Map<
String, dynamic> json, {ValueSerializer? serializer}) -
factory
Properties
- accountKey → String
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seq → String
-
final
- subscriptionId → String
-
final
- updatedAt → DateTime
-
final
Methods
-
copyWith(
{String? accountKey, String? subscriptionId, String? seq, DateTime? updatedAt}) → StoredCheckpoint -
copyWithCompanion(
KalamCheckpointsCompanion data) → StoredCheckpoint -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toColumns(
bool nullToAbsent) → Map< String, Expression< Object> > -
Converts this object into a map of column names to expressions to insert
or update.
override
-
toCompanion(
bool nullToAbsent) → KalamCheckpointsCompanion -
toJson(
{ValueSerializer? serializer}) → Map< String, dynamic> -
Converts this object into a representation that can be encoded with
json. Theserializercan be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.override -
toJsonString(
{ValueSerializer? serializer}) → String -
Converts this object into a json representation. The
serializercan be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.inherited -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override