StoredRowState class

Inheritance
Implemented types

Constructors

StoredRowState({required String accountKey, required String tableId, required String rowKey, required String phase, String? actionId, required int attemptCount, DateTime? nextRetryAt, String? errorCode, String? errorMessage, String? lastServerSeq, String? pendingValuesJson, required bool tombstone, required DateTime updatedAt})
const
StoredRowState.fromJson(Map<String, dynamic> json, {ValueSerializer? serializer})
factory

Properties

accountKey String
final
actionId String?
final
attemptCount int
final
errorCode String?
final
errorMessage String?
final
hashCode int
The hash code for this object.
no setteroverride
lastServerSeq String?
final
nextRetryAt DateTime?
final
pendingValuesJson String?
final
phase String
final
rowKey String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tableId String
final
tombstone bool
final
updatedAt DateTime
final

Methods

copyWith({String? accountKey, String? tableId, String? rowKey, String? phase, Value<String?> actionId = const Value.absent(), int? attemptCount, Value<DateTime?> nextRetryAt = const Value.absent(), Value<String?> errorCode = const Value.absent(), Value<String?> errorMessage = const Value.absent(), Value<String?> lastServerSeq = const Value.absent(), Value<String?> pendingValuesJson = const Value.absent(), bool? tombstone, DateTime? updatedAt}) StoredRowState
copyWithCompanion(KalamRowStatesCompanion data) StoredRowState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
override
toCompanion(bool nullToAbsent) KalamRowStatesCompanion
toJson({ValueSerializer? serializer}) Map<String, dynamic>
Converts this object into a representation that can be encoded with json. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
override
toJsonString({ValueSerializer? serializer}) String
Converts this object into a json representation. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override