KalamRowStatesCompanion class
Constructors
-
KalamRowStatesCompanion({Value<String> accountKey = const Value.absent(), Value<String> tableId = const Value.absent(), Value<String> rowKey = const Value.absent(), Value<String> phase = const Value.absent(), Value<String?> actionId = const Value.absent(), Value<int> attemptCount = const Value.absent(), Value<DateTime?> nextRetryAt = const Value.absent(), Value<String?> errorCode = const Value.absent(), Value<String?> errorMessage = const Value.absent(), Value<String?> lastServerSeq = const Value.absent(), Value<String?> pendingValuesJson = const Value.absent(), Value<bool> tombstone = const Value.absent(), Value<DateTime> updatedAt = const Value.absent(), Value<int> rowid = const Value.absent()})
-
const
-
KalamRowStatesCompanion.insert({required String accountKey, required String tableId, required String rowKey, required String phase, Value<String?> actionId = const Value.absent(), Value<int> attemptCount = const Value.absent(), Value<DateTime?> nextRetryAt = const Value.absent(), Value<String?> errorCode = const Value.absent(), Value<String?> errorMessage = const Value.absent(), Value<String?> lastServerSeq = const Value.absent(), Value<String?> pendingValuesJson = const Value.absent(), Value<bool> tombstone = const Value.absent(), required DateTime updatedAt, Value<int> rowid = const Value.absent()})
-
Methods
-
copyWith({Value<String>? accountKey, Value<String>? tableId, Value<String>? rowKey, Value<String>? phase, Value<String?>? actionId, Value<int>? attemptCount, Value<DateTime?>? nextRetryAt, Value<String?>? errorCode, Value<String?>? errorMessage, Value<String?>? lastServerSeq, Value<String?>? pendingValuesJson, Value<bool>? tombstone, Value<DateTime>? updatedAt, Value<int>? rowid})
→ KalamRowStatesCompanion
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toColumns(bool nullToAbsent)
→ Map<String, Expression<Object>>
-
Converts this object into a map of column names to expressions to insert
or update.
override
-
toString()
→ String
-
A string representation of this object.
override
Static Methods
-
custom({Expression<String>? accountKey, Expression<String>? tableId, Expression<String>? rowKey, Expression<String>? phase, Expression<String>? actionId, Expression<int>? attemptCount, Expression<DateTime>? nextRetryAt, Expression<String>? errorCode, Expression<String>? errorMessage, Expression<String>? lastServerSeq, Expression<String>? pendingValuesJson, Expression<bool>? tombstone, Expression<DateTime>? updatedAt, Expression<int>? rowid})
→ Insertable<StoredRowState>
-