StoredAction class
Inheritance
Implemented types
Constructors
StoredAction ({required String id , required String accountKey , required String actionKey , required int version , required String kind , required String payloadJson , required String status , String ? orderingKey , String ? rowTableId , String ? rowKey , required int queuePosition , required int attemptCount , DateTime ? nextAttemptAt , String ? lastError , required DateTime createdAt , required DateTime updatedAt })
const
StoredAction.fromJson (Map <String , dynamic > json , {ValueSerializer ? serializer })
factory
Methods
copyWith ({String ? id , String ? accountKey , String ? actionKey , int ? version , String ? kind , String ? payloadJson , String ? status , Value <String ? > orderingKey = const Value.absent() , Value <String ? > rowTableId = const Value.absent() , Value <String ? > rowKey = const Value.absent() , int ? queuePosition , int ? attemptCount , Value <DateTime ? > nextAttemptAt = const Value.absent() , Value <String ? > lastError = const Value.absent() , DateTime ? createdAt , DateTime ? updatedAt })
→ StoredAction
copyWithCompanion (KalamActionsCompanion data )
→ StoredAction
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns (bool nullToAbsent )
→ Map <String , Expression <Object > >
Converts this object into a map of column names to expressions to insert
or update.
override
toCompanion (bool nullToAbsent )
→ KalamActionsCompanion
toJson ({ValueSerializer ? serializer })
→ Map <String , dynamic >
Converts this object into a representation that can be encoded with
json. The serializer can be used to configure how individual values
will be encoded. By default, DriftRuntimeOptions.defaultSerializer will
be used. See ValueSerializer.defaults for details.
override
toJsonString ({ValueSerializer ? serializer })
→ String
Converts this object into a json representation. The serializer can be
used to configure how individual values will be encoded. By default,
DriftRuntimeOptions.defaultSerializer will be used. See
ValueSerializer.defaults for details.
inherited
toString ()
→ String
A string representation of this object.
override